==> aws-cdk-scala_2.12-0.7.0-sources.jar: io/burkard/cdk/services/apigateway/SpecRestApi.scala <==
package io.burkard.cdk.services.apigateway

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SpecRestApi {

  def apply(
    internalResourceId: String,
    apiDefinition: software.amazon.awscdk.services.apigateway.ApiDefinition,
    endpointExportName: Option[String] = None,
    cloudWatchRole: Option[Boolean] = None,
    domainName: Option[software.amazon.awscdk.services.apigateway.DomainNameOptions] = None,
    failOnWarnings: Option[Boolean] = None,
    deployOptions: Option[software.amazon.awscdk.services.apigateway.StageOptions] = None,
    retainDeployments: Option[Boolean] = None,
    disableExecuteApiEndpoint: Option[Boolean] = None,
    deploy: Option[Boolean] = None,
    restApiName: Option[String] = None,
    endpointTypes: Option[List[_ <: software.amazon.awscdk.services.apigateway.EndpointType]] = None,
    parameters: Option[Map[String, String]] = None,
    policy: Option[software.amazon.awscdk.services.iam.PolicyDocument] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.apigateway.SpecRestApi =
    software.amazon.awscdk.services.apigateway.SpecRestApi.Builder
      .create(stackCtx, internalResourceId)
      .apiDefinition(apiDefinition)
      .endpointExportName(endpointExportName.orNull)
      .cloudWatchRole(cloudWatchRole.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .domainName(domainName.orNull)
      .failOnWarnings(failOnWarnings.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .deployOptions(deployOptions.orNull)
      .retainDeployments(retainDeployments.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .disableExecuteApiEndpoint(disableExecuteApiEndpoint.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .deploy(deploy.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .restApiName(restApiName.orNull)
      .endpointTypes(endpointTypes.map(_.asJava).orNull)
      .parameters(parameters.map(_.asJava).orNull)
      .policy(policy.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.15.0-sources.jar: io/burkard/cdk/services/apigateway/SpecRestApi.scala <==
package io.burkard.cdk.services.apigateway

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SpecRestApi {

  def apply(
    internalResourceId: String,
    apiDefinition: software.amazon.awscdk.services.apigateway.ApiDefinition,
    endpointExportName: Option[String] = None,
    cloudWatchRole: Option[Boolean] = None,
    domainName: Option[software.amazon.awscdk.services.apigateway.DomainNameOptions] = None,
    failOnWarnings: Option[Boolean] = None,
    deployOptions: Option[software.amazon.awscdk.services.apigateway.StageOptions] = None,
    retainDeployments: Option[Boolean] = None,
    disableExecuteApiEndpoint: Option[Boolean] = None,
    deploy: Option[Boolean] = None,
    restApiName: Option[String] = None,
    endpointTypes: Option[List[_ <: software.amazon.awscdk.services.apigateway.EndpointType]] = None,
    parameters: Option[Map[String, String]] = None,
    policy: Option[software.amazon.awscdk.services.iam.PolicyDocument] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.apigateway.SpecRestApi =
    software.amazon.awscdk.services.apigateway.SpecRestApi.Builder
      .create(stackCtx, internalResourceId)
      .apiDefinition(apiDefinition)
      .endpointExportName(endpointExportName.orNull)
      .cloudWatchRole(cloudWatchRole.map(Boolean.box).orNull)
      .domainName(domainName.orNull)
      .failOnWarnings(failOnWarnings.map(Boolean.box).orNull)
      .deployOptions(deployOptions.orNull)
      .retainDeployments(retainDeployments.map(Boolean.box).orNull)
      .disableExecuteApiEndpoint(disableExecuteApiEndpoint.map(Boolean.box).orNull)
      .deploy(deploy.map(Boolean.box).orNull)
      .restApiName(restApiName.orNull)
      .endpointTypes(endpointTypes.map(_.asJava).orNull)
      .parameters(parameters.map(_.asJava).orNull)
      .policy(policy.orNull)
      .build()
}
